#
# spec file for package qalculate-qt
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           qalculate-qt
Version:        5.5.1
Release:        1.1
Summary:        Multi-purpose cross-platform desktop calculator
License:        GPL-2.0-or-later
Group:          Productivity/Scientific/Math
URL:            https://qalculate.github.io
Source0:        https://github.com/Qalculate/qalculate-qt/releases/download/v%{version}/qalculate-qt-%{version}.tar.gz
BuildRequires:  automake
BuildRequires:  gcc-c++
BuildRequires:  hicolor-icon-theme
BuildRequires:  intltool
BuildRequires:  libnghttp2-devel
BuildRequires:  libtool
BuildRequires:  pkgconfig
# compilation fails on 5.12.x
BuildRequires:  pkgconfig(Qt6Core)
BuildRequires:  qt6-base-common-devel
BuildRequires:  qt6-base-devel
BuildRequires:  qt6-tools-linguist
BuildRequires:  pkgconfig(Qt6Network)
BuildRequires:  pkgconfig(Qt6Widgets)
BuildRequires:  pkgconfig(libqalculate) >= %{version}
BuildRequires:  pkgconfig(libxml-2.0)
Requires:       libqalculate23 >= %{version}

%description
Qalculate! is a multi-purpose cross-platform desktop calculator. It is
simple to use but provides power and versatility normally reserved for
complicated math packages, as well as useful tools for everyday needs
(such as currency conversion and percent calculation). Features include a
large library of customizable functions, unit calculations and conversion,
symbolic calculations (including integrals and equations), arbitrary
precision, uncertainty propagation, interval arithmetic, plotting, and a
user-friendly interface (QT, GTK+ and CLI).

%prep
%autosetup -p1

%build
%qmake6 PREFIX=%{_prefix}
make %{?_smp_mflags}

%install
%qmake6_install

%files
%license COPYING
%{_bindir}/%{name}
%{_datadir}/applications/io.github.Qalculate.qalculate-qt.desktop
%dir %{_datadir}/icons/hicolor/16x16
%dir %{_datadir}/icons/hicolor/16x16/apps
%{_datadir}/icons/hicolor/16x16/apps/qalculate-qt.png
%dir %{_datadir}/icons/hicolor/22x22
%dir %{_datadir}/icons/hicolor/22x22/apps
%{_datadir}/icons/hicolor/22x22/apps/qalculate-qt.png
%dir %{_datadir}/icons/hicolor/32x32
%dir %{_datadir}/icons/hicolor/32x32/apps
%{_datadir}/icons/hicolor/32x32/apps/qalculate-qt.png
%dir %{_datadir}/icons/hicolor/64x64
%dir %{_datadir}/icons/hicolor/64x64/apps
%{_datadir}/icons/hicolor/64x64/apps/qalculate-qt.png
%dir %{_datadir}/icons/hicolor/128x128
%dir %{_datadir}/icons/hicolor/128x128/apps
%{_datadir}/icons/hicolor/128x128/apps/qalculate-qt.png
%dir %{_datadir}/icons/hicolor/scalable
%dir %{_datadir}/icons/hicolor/scalable/apps
%{_datadir}/icons/hicolor/scalable/apps/qalculate-qt.svg
%{_mandir}/man?/%{name}.?%{ext_man}
%{_datadir}/metainfo/io.github.Qalculate.qalculate-qt.metainfo.xml
%dir %{_datadir}/qalculate-qt
%dir %{_datadir}/qalculate-qt/translations
%{_datadir}/qalculate-qt/translations/qalculate-qt_ca.qm
%{_datadir}/qalculate-qt/translations/qalculate-qt_de.qm
%{_datadir}/qalculate-qt/translations/qalculate-qt_en.qm
%{_datadir}/qalculate-qt/translations/qalculate-qt_es.qm
%{_datadir}/qalculate-qt/translations/qalculate-qt_fr.qm
%{_datadir}/qalculate-qt/translations/qalculate-qt_nl.qm
%{_datadir}/qalculate-qt/translations/qalculate-qt_pt_BR.qm
%{_datadir}/qalculate-qt/translations/qalculate-qt_pt_PT.qm
%{_datadir}/qalculate-qt/translations/qalculate-qt_ru.qm
%{_datadir}/qalculate-qt/translations/qalculate-qt_sl.qm
%{_datadir}/qalculate-qt/translations/qalculate-qt_sv.qm
%{_datadir}/qalculate-qt/translations/qalculate-qt_zh_CN.qm

%changelog
* Thu Mar  6 2025 pallas wept <pallaswept@proton.me>
- Update to 5.5.1
  * Option to automatically calculate the current selection, in tooltip
  * Option to calculate the current selection, once in history
  * Toggle fraction format action for custom keyboard shortcuts and keypad buttons
  * Fix copy unformatted ASCII without units when unit is placed before quantity
  * Fix solve() function with replace() function as first argument (fixes solve2() function) (libqalculate)
  * Fix "where" operator using (in)equality in variable (libqalculate)
  * Return x=ae^(ir) (with r instead of n) for abs(x)=x (libqalculate)
  * Minor bug fixes and feature enhancements
* Tue Jan 14 2025 Paolo Stivanin <info@paolostivanin.com>
- Update to 5.5.0:
  * Place approximate value before exact in calculate
    as you type result
  * Option to disable cursor blinking
  * Set ans variable to solution(s) of equation
    (as if solve() function were used)
  * Fix display of units automatically appended to expression in
    parse status
  * Fix reading of expressions from file
  * a(i) and a[i] syntax (the latter with support for functions)
    for element in vector (libqalculate)
  * New function: factor() (libqalculate)
  * Minor bug fixes and feature enhancements
* Thu Dec 19 2024 pallas wept <pallaswept@proton.me>
- Build with Qt6
- Update to 5.4.0
  * Apply dual approximation/fraction to calculate as you type
    result, as regular result but with length restriction
  * Add option to add/edit comment to history context menu, and save
    comments in result on exit
  * Add "Search by Date" (also shows the date of the expression) to
    history context menu
  * Option to automatically group digits in input
  * Option, in menu, to open settings folder(s)
  * Improve decision to automatically convert unchanged quantity
    with unit
  * Fix equals sign for calculate as you type result
  * Fix segfault with calculate as you type of "-(300K" and similar
  * Fix saving of two's complement input settings
  * Fix erroneous HTML output after format of result with
    error/warning has been updated
  * Updated French translation
  * New functions: tripleProduct(), multilimit() (libqalculate)
  * Fix case conversion of µ to M and similar (libqalculate)
  * Fix segfault with very large integer raised by very large
    integer (libqalculate)
  * Minor bug fixes and feature enhancements
- Update to 5.3.0
  * Show language menu in preferences on all platforms
  * Change "Hide number pad" to "Always show number pad", and add
    separate number pad when the option is not enabled
  * Improve initial value and clear all other fields when edited
    field is empty, in number bases and floating point conversion
    dialogs
  * Allow unit expressions for insert unit action, for custom
    shortcuts and buttons
  * Set minimum characters to two for all completion with "Limited
    full completion"
  * Support x without backslash for custom function argument
    condition
  * Update parsed expression and calculate-as-you-type result if
    variable, function, or unit in expression has changed
  * Improve support for small displays with low resolution/high
    scaling
  * Update chain mode to match behaviour in Gtk UI
  * Update calendar and floating point conversion dialogs after
    expression calculation
  * Delay creation of keypads, completion list, and functions,
    units, and variables toolbar menus until shown
  * Portuguese (pt_PT) translation
  * Fixes for overwrite input mode
  * Fix unresponsive expression field in some cases after smart
    parentheses has been applied
  * Fix completion with both custom app font and custom expression
    font set
  * Fix input of max value for number argument
  * Fix shift + "^°" key press (input °) with German keyboard layout
  * Fix memory leaks (libqalculate)
  * Fix segfault with recursive (self-referencing) function
    (libqalculate)
  * Fix input of negative exponent in scientific e notation with RPN
    syntax (libqalculate)
  * Fix parsing of 1°2'3" as 1°+2'+3" (libqalculate)
  * Improve handling of "where" expressions with inequalities
    (libqalculate)
  * Fix definite integral for 1/sqrt(1-x^2), with limits
    higher/lower than or equal to -1 and 1 (libqalculate)
  * Fix crash with empty vector in plot function, e.g. plot([])
    (libqalculate)
  * Fix "did you mean..." warning for two implicitly multiplicated
    functions without space between (e.g. "atan2(a,b)atan2(c,d)")
    (libqalculate)
  * Fix inability to abort randpoisson() with very high rate value
    (libqalculate)
  * Minor bug fixes and feature enhancements
- Update to 5.2.0
  * Option (enabled by default) to show expression status (parsed
    expression and calculated value) as you type in history list,
    instead of in tooltip (Qt)
  * Option to hide toolbar (Qt)
  * Option to preserve height of history list when keypad or number
    bases are shown/hidden (Qt)
  * Headers for keyboard shortcuts and actions lists to allow custom
    sorting (Qt)
  * Option to show/hide hidden units (hidden by default) in units
    window (Qt)
  * Option to change the max number of history lines saved (GTK, Qt)
  * Reduced minimum height (one line) of expression field (Qt)
  * Fix subsequent tab completions after completion of unit with
    prefix (GTK, Qt)
  * Fix convert button text, when toolbar style is not icon only
    (Qt)
  * Fix history list not cleared before reload if there are exactly
    one item (Qt)
  * Physical constants updated with CODATA 2022 values
    (libqalculate)
  * New function: allroots() (libqalculate)
  * New units: therm, thermie, IUNS calorie, rpm (libqalculate)
  * Additional names/symbols for turn unit (libqalculate)
  * Use symbol "cal" for thermochemical (instead of international
    table) calorie (libqalculate)
  * Change title and names/symbols of weak mixing angle (prepend
    "sin2" to theta variants) (libqalculate)
  * Return exact negative integers in log10() (libqalculate)
  * More conservative handling of infinity in equations
    (libqalculate)
  * Remove n from equation solution if possible using assumptions of
    x (libqalculate)
  * Fix unnecessary parenthesis, with wrong color for closing
    bracket, around unit with exponent in HTML output (libqalculate)
  * Fix input of scientific E-notation using lowercase e in numbers
    using concise interval notation, in expressions (libqalculate)
  * Fix "bit width" and "signed integer" arguments in setbits()
    (libqalculate)
  * Fix a^(f(x))=a^(b*g(x)) where b=2 or b=3 (libqalculate)
  * Fix auto/dual approximation with "where" expression
    (libqalculate)
  * Fix "where" expressions with multiple inequality statements for
    a single variable, e.g. "where x>0 and x<10" (libqalculate)
  * Fix crash when a variable name/symbol with more than 20
    characters is used in "where" expression (libqalculate)
  * Minor bug fixes and feature enhancements
* Mon Jul  1 2024 Christophe Marin <christophe@krop.fr>
- Update to 5.1.0.
  Check https://github.com/Qalculate/qalculate-qt/releases for
  older changes list. Changes since 5.0.0:
  * Improved history list efficiency
  * Add two's complement input and binary bits to preferences
  * Ask for the desired interpretation the first time percent
    addition is used (e.g. 100 + 10%% equals 110 or 100.1)
  * Hide expression tooltip (after 300 ms) when input resumes,
    if delayed expression status is enabled
  * Download button in dialog shown when new version is
    available, on Windows
  * Fix AltGr for input of operators on Windows
  * Support for solving equations containing if() function
    (libqalculate)
  * Support for solving root(a, x)=b (requires rational
    value for ln(a)/ln(b)) (libqalculate)
  * New functions: powertower() and multiples() (libqalculate)
  * New units for solar radius, mass, and luminosity (libqalculate)
  * Use parentheses for exponent using scientific notation (with
    power of 10) (libqalculate)
  * Support integer factorization of integers in matrix/vector,
    and of numerator and denominator in rational number
    (libqalculate)
  * Relaxed conditions for (x^a)^b = x^(a × b) and
    x^a × x^b = x^(a + b) when complex numbers are
    deactivated (fixes segfaults) (libqalculate)
  * Fix (ax + n)^2 > 1, where n is even and a is not 1,
    returning false (libqalculate)
  * Fix setbits() function (libqalculate)
  * Fix Number::equals(0, ..., true) when number is infinite
    (affects replace() function) (libqalculate)
  * Fix a^(f(x))=a^(b*g(x)) where b=2 or b=3 (libqalculate
    v5.1.1)
  * Minor bug fixes and feature enhancements
* Sat May 11 2024 jun wang <jgwang@suse.com>
- Update to 4.9.0
  + Changes from 4.9.0
  * Support for specifying a fixed denominator for display of
    fractions
  * Return gcd of numerators divided by lcm of denominators in
    gcd() with non-integer rational numbers, and vice versa for
    lcm()
  * Add units for mean Gregorian and tropical years
  * Ignore underscore in number
  * Replace defunct exchange rates source and fix bitcoin
    exchange rate
  * Fix asin(x)=a, acos(x)=a, and atan(x)=a, when a contains an
    angle unit and default angle unit is set
  * Fix output of value converted to unit expression with
    numerical multiplier in denominator, e.g. "➞ L/(100 km)"
  * Fix segfault when trying to solve
    "(x*sqrt(x)-y*sqrt(y))/(sqrt(x)-sqrt(y))=x+sqrt(x*y)+y"
  * Fix parsing of case insensitive object name ending with
    Unicode character when followed by another Unicode character
    in expression, e.g. "микрометр"
  * Always add result to history (even if identical to previous)
    if expression contains a function generating a random
    number (GTK, Qt)
  * Prefer capitalized function name (over name with underscore),
    when completing function name (GTK, Qt)
  * Improve decision to (not) update calculate-as-you-type
    result when last character is an operator (GTK)
  * Add percent and permille output options in rational number
    form menu (GTK)
  * Fix keypad button (up/down) for cycling through expression
    history (GTK)
  * Restore decimal number base after closing programming
    keypad (Qt)
  * Improve appearance of conversion menu (Qt)
  * Save position of main window even if size has not changed
    from the default (Qt)
  * Fix custom middle click button action (Qt)
  * Fix immediate calculation after selecting to-conversion
    completion (Qt)
  * Add history command, listing expression history (CLI)
  * Display all exponents 0-9 using Unicode superscript
    characters if these are the only exponents in the
    expression (CLI)
  * Minor bug fixes and feature enhancements
  + Changes from 4.8.1
  * Fix besselj() and bessely()
  * Fix display of matrices and vectors with complex number
    form other than rectangular (default)
  * Fix conflict between decibel units (e.g. "0dB") and
    duodecimal 0d… syntax (now requires at least two digits)
  * Fixes for title options in plot() function
  * Add additional buttons and button menus to general
    keypad (Qt)
  * Add option to show all functions, units, and variables in
    tool button menus (Qt)
  * Add recently used objects to functions, units, and variables
    menus (Qt)
  * Add option to bypass dialog for functions in menu (Qt)
  * Add option, in context menu, to display text for tool
    buttons (Qt)
  * Open functions, units, and variables tool button menus using
    long-press or right-click (in addition to arrow button),
    and add keyboard shortcuts (Qt)
  * Use keypad tool button menu as context menu and show keypad
    type in title bar of keypad (Qt)
  * Auto-update number bases above programming keypad when
    entering simple integers, even if calculate-as-you-type is
    deactivated (GTK)
  + Changes from 4.8.0
  * Concise (e.g. "1.2345(67)") and relative (e.g. "5+/-2%%")
    notation for output and input (disabled by default for
    concise notation) of interval
  * Optimize rest of unit expression when converting to partial
    (insufficient) expression (e.g. 18MA×100ns to J = 1.8 J/V)
  * Round high precision intervals enclosing integers for
    integer arguments
  * Add support for specifying position of sign bit in floating
    point functions
  * New derived units: Debye, C·m, Daraf, F^-1, V/C, N/C, kcal,
    kcal/g, kJ
  * Use international foot as base unit for rod
  * Fix fibonacci() for non-integers and recursive use
  * Fix conversion options presented for speed units
    (and possibly other)
  * Update dialogs for editing of variables, functions, units,
    etc. to match the corresponding dialogs in the Qt UI (GTK)
  * Show user-defined objects in a separate category in menus
    and dialogs (GTK)
  * Add option to disable tooltips in keypad or everywhere
    (GTK, Qt)
  * Add option to disable units and to interpret unrecognized
    symbols as variables (unknowns) to preferences (Qt)
  * Make closing of application with Escape key optional and
    disabled by default (GTK, Qt)
  * Hide name column in conversion list when applied to current
    result (Qt)
  * Add temporary option to unknown variable edit dialog
    (GTK, Qt)
  * Add Microship (PIC16/17) 24 and 32 bit floating point
    formats (GTK, Qt)
  * Fix initial height of list and description in units window
    (GTK)
  * Minor bug fixes and feature enhancements
  + Changes from 4.7.0
  * Support for custom default angle unit, e.g. turn, arcsec,
    arcmin
  * Append default angle unit (instead of always radians) when
    converting value without unit to angle unit
  * More consistent addition and removal of angle unit from
    function arguments
  * Always interpret ./, .*, and .^ as entrywise operators if
    user intention is unclear
  * Change order of operations to place entrywise and ordinary
    operators on the same precedence level
  * Add function, kron(), for Kronecker product, and constants
    for Pauli matrices
  * Add radius to planets dataset and update other properties
  * Support replacement of unknown variables within variable
    values
  * Fix besselj(0, 0)
  * Fix incomplete calculation in tan() with try exact
    approximation
  * Fix 0/0=0 equality (do not return true) and output of 2/0
    (and similar)
  * Fixes and improvements for newtonsolve() and secantsolve()
  * Fix segfault when MathStructure is deleted after Calculator,
    and in destructor of calculated DynamicVariable
    (called from Calculator destructor)
  * Do not save mode on exit if "-defaults" command line switch
    where used (CLI)
  * Allow multiple actions for keyboard shortcuts (GTK, Qt)
  * Add toggle precision, and min, max, or min and max decimals
    to available shortcut and button actions (GTK, Qt)
  * Add option to exclude units for unformatted ASCII copy
    (GTK, Qt)
  * Add optional value to copy result action, allowing
    expression copy and formatting selection (GTK, Qt)
  * Fix copy unformatted ASCII when local digit group separator
    is same as selected decimal separator (GTK, Qt)
  * Add option to automatically copy result (Qt)
  * Always set (primary) selection clipboard contents when whole
    expression is selected or selection is cleared, e.g. after
    calculation (Qt)
  * Improve support dark mode and high contrast modes, and
    change default style to Fusion, on Windows (Qt)
  * Minor bug fixes and feature enhancements
* Thu Apr 20 2023 Paolo Stivanin <info@paolostivanin.com>
- Update to 4.6.1:
  * More robust and consistent default language detection and option
    to change language on Windows
  * Option to change symbols used for output of digits 10 and 11 in
    duodecimal numbers (use A and B as default digits)
* Tue Dec 27 2022 Paolo Stivanin <info@paolostivanin.com>
- Update to 4.5.0:
  * Use history font for RPN stack list (GTK, Qt)
  * Use log() instead of log2() as alternative action on "ln" keypad button (Qt)
  * Fix completion (including segfaults) and expression tooltip on Wayland (Qt)
  * Fix RPN mode deactivated after application loses focus (Qt)
* Fri Nov 11 2022 Paolo Stivanin <info@paolostivanin.com>
- Fix spec file, update QT min version.
* Thu Nov 10 2022 Paolo Stivanin <info@paolostivanin.com>
- Initial OBS release.
